<div class="ablog-sidebar-item ablog__postcard2">
  {% if post.published and post.date != post.update %}
  <li id="published">
    <span>
      {% if fa %}
      <i class="fa fa-fw fa-edit"></i>
      {% else %} {{ gettext('Update') }}: {% endif %}
    </span>
    {{ post.update.strftime(ablog.post_date_format) }}
  </li>
  {% endif %} {% if post.author %}
  <li id="ablog-sidebar-item author ablog__author">
    <span>
      {% if fa %}
      <i class="fa-fw fa fa-user"></i>
      {% else %} {{ gettext('Author') }}: {% endif %}
    </span>
    {% for coll in post.author %} {% if coll|length %}
    <a href="{{ pathto(coll.docname) }}">{{ coll }}</a>
    {% if loop.index < post.author|length %} , {% endif %} {% else %} {{ coll }}
    {% if loop.index < post.author|length %} , {% endif %} {% endif %} {% endfor
    %}
  </li>
  {% endif %} {% if post.location %}
  <li id="ablog-sidebar-item location ablog__location">
    <span>
      {% if fa %}
      <i class="fa-fw fa fa-location-arrow"></i>
      {% else %} {{ gettext('Location') }}: {% endif %}
    </span>
    {% for coll in post.location %} {% if coll|length %}
    <a href="{{ pathto(coll.docname) }}">{{ coll }}</a>
    {% if loop.index < post.location|length %} , {% endif %} {% else %} {{ coll
    }} {% if loop.index < post.location|length %} , {% endif %} {% endif %} {%
    endfor %}
  </li>
  {% endif %} {% if post.language %}
  <li id="ablog-sidebar-item language ablog__language">
    <span>
      {% if fa %}
      <i class="fa-fw fa fa-language"></i>
      {% else %} {{ gettext('Language') }}: {% endif %}
    </span>
    {% for coll in post.language %} {% if coll|length %}
    <a href="{{ pathto(coll.docname) }}">{{ coll }}</a>
    {% if loop.index < post.language|length %} , {% endif %} {% else %} {{ coll
    }} {% if loop.index < post.language|length %} , {% endif %} {% endif %} {%
    endfor %}
  </li>
  {% endif %} {% if post.category %}
  <li id="ablog-sidebar-item category ablog__category">
    <span>
      {% if fa %}
      <i class="fa-fw fa fa-folder-open"></i>
      {% else %} {{ gettext('Category') }}: {% endif %}
    </span>
    {% for coll in post.category %} {% if coll|length %}
    <a href="{{ pathto(coll.docname) }}">{{ coll }}</a>
    {% if loop.index < post.category|length %} , {% endif %} {% else %} {{ coll
    }} {% if loop.index < post.category|length %} , {% endif %} {% endif %} {%
    endfor %}
  </li>
  {% endif %} {% if post.tags %}
  <li id="ablog-sidebar-item tags ablog__tags">
    <span>
      {% if post.tags|length > 1 %} {% if fa %}
      <i class="fa-fw fa fa-tags"></i>
      {% else %} {{ gettext('Tags') }}: {% endif %} {% else %} {% if fa %}
      <i class="fa-fw fa fa-tag"></i>
      {% else %} {{ gettext('Tag') }}: {% endif %}{% endif %}
    </span>
    {% for coll in post.tags %} {% if coll|length %}
    <a href="{{ pathto(coll.docname) }}">{{ coll }}</a>
    {% if loop.index < post.tags|length %} {% endif %} {% else %} {{ coll }} {%
    if loop.index < post.tags|length %} {% endif %} {% endif %} {% endfor %}
  </li>
  {% endif %} {% if ablog.disqus_shortname and (ablog[pagename].published or
  ablog.disqus_drafts) %}
  <li id="ablog-sidebar-item comments ablog__comments">
    <script type="text/javascript">
      var disqus_shortname = "{{ ablog.disqus_shortname }}";

      (function () {
        var s = document.createElement("script");
        s.async = true;
        s.type = "text/javascript";
        s.src = "//" + disqus_shortname + ".disqus.com/count.js";
        (
          document.getElementsByTagName("HEAD")[0] ||
          document.getElementsByTagName("BODY")[0]
        ).appendChild(s);
      })();
    </script>
    {% if fa %}
    <i class="fa-fw fa fa-comments"></i>
    {% endif %}
    <a
      href="{%- if pagename != post.docname -%} {{ pathto(post.docname) }} {%- endif -%} #disqus_thread"
      data-disqus-identifier="/{{ post.docname }}/"
    >
      {% if not fa %} Comments {% endif %}
    </a>
  </li>
  {% endif %}
</div>
