{# prev/next are not set for drafts #} {% set post = ablog[pagename] %} {% if
post.published and ablog.post_show_prev_next %}
<div class="section ablog__prev-next">
  <span class="ablog__prev">
    {% if post.prev %} {% if not ablog.fontawesome %} {{ gettext('Previous') }}:
    {% endif %}
    <a href="{{ pathto(post.prev.docname) }}{{ anchor(post.prev) }}">
      {% if ablog.fontawesome %}
      <i class="fa fa-arrow-circle-left"></i>
      {% endif %}
      <span>{{ post.prev.title }}</span>
    </a>
    {% endif %}
  </span>
  <span class="ablog__spacer">&nbsp;</span>
  <span class="ablog__next">
    {% if post.next %} {% if not ablog.fontawesome %} {{ gettext('Next') }}: {%
    endif %}
    <a href="{{ pathto(post.next.docname) }}{{ anchor(post.next) }}">
      <span>{{ post.next.title }}</span>
      {% if ablog.fontawesome %}
      <i class="fa fa-arrow-circle-right"></i>
      {% endif %}
    </a>
    {% endif %}
  </span>
</div>
{% endif %}
