{{ warning("locations.html is an old template path, that is no longer used by
ablog. Please use ablog/locations.html instead.") }} {% if ablog.location %}
<div class="ablog-sidebar-item ablog__locations">
  <h3>
    <a href="{{ pathto(ablog.location.path) }}">{{ gettext('Locations') }}</a>
  </h3>
  <ul>
    {% for coll in ablog.location %} {% if coll %}
    <li>
      <a href="{{ pathto(coll.docname) }}">{{ coll }} ({{ coll|length }})</a>
    </li>
    {% endif %} {% endfor %}
  </ul>
</div>
{% endif %}
